@@ -26,20 +26,20 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V5::Common::GenderInfo;
-use Google::Ads::GoogleAds::V5::Common::DeviceInfo;
-use Google::Ads::GoogleAds::V5::Enums::ReachPlanAdLengthEnum
+use Google::Ads::GoogleAds::V6::Common::GenderInfo;
+use Google::Ads::GoogleAds::V6::Common::DeviceInfo;
+use Google::Ads::GoogleAds::V6::Enums::ReachPlanAdLengthEnum
   qw(FIFTEEN_OR_TWENTY_SECONDS);
-use Google::Ads::GoogleAds::V5::Enums::GenderTypeEnum qw(MALE FEMALE);
-use Google::Ads::GoogleAds::V5::Enums::DeviceEnum qw(DESKTOP MOBILE TABLET);
-use Google::Ads::GoogleAds::V5::Enums::ReachPlanAgeRangeEnum
+use Google::Ads::GoogleAds::V6::Enums::GenderTypeEnum qw(MALE FEMALE);
+use Google::Ads::GoogleAds::V6::Enums::DeviceEnum qw(DESKTOP MOBILE TABLET);
+use Google::Ads::GoogleAds::V6::Enums::ReachPlanAgeRangeEnum
   qw(AGE_RANGE_18_65_UP);
-use Google::Ads::GoogleAds::V5::Services::ReachPlanService::PlannedProduct;
-use Google::Ads::GoogleAds::V5::Services::ReachPlanService::Preferences;
-use Google::Ads::GoogleAds::V5::Services::ReachPlanService::CampaignDuration;
-use Google::Ads::GoogleAds::V5::Services::ReachPlanService::Targeting;
+use Google::Ads::GoogleAds::V6::Services::ReachPlanService::PlannedProduct;
+use Google::Ads::GoogleAds::V6::Services::ReachPlanService::Preferences;
+use Google::Ads::GoogleAds::V6::Services::ReachPlanService::CampaignDuration;
+use Google::Ads::GoogleAds::V6::Services::ReachPlanService::Targeting;
 use
-  Google::Ads::GoogleAds::V5::Services::ReachPlanService::GenerateReachForecastRequest;
+  Google::Ads::GoogleAds::V6::Services::ReachPlanService::GenerateReachForecastRequest;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -92,8 +92,8 @@ sub show_plannable_locations {
   print "Plannable Locations:\n";
   print "Name,\tId,\tParentCountryId\n";
   foreach my $location (@{$response->{plannableLocations}}) {
-    printf "'%s',\t%d,\t%d\n", $location->{name}, $location->{id},
-      $location->{parentCountryId};
+    printf "'%s',\t%s,\t%d\n", $location->{name}, $location->{id},
+      $location->{parentCountryId} ? $location->{parentCountryId} : 0;
   }
 }
 
@@ -107,7 +107,8 @@ sub show_plannable_products {
 
   printf "Plannable Products for location %d:\n", $location_id;
   foreach my $product (@{$response->{productMetadata}}) {
-    printf "%s\n", $product->{plannableProductCode};
+    printf "%s : '%s'\n", $product->{plannableProductCode},
+      $product->{plannableProductName};
     print "Age Ranges:\n";
     foreach my $age_range (@{$product->{plannableTargeting}{ageRanges}}) {
       printf "\t- %s\n", $age_range;
@@ -138,14 +139,14 @@ sub forecast_manual_mix {
 
   # See list_plannable_products on ReachPlanService to retrieve a list of valid
   # plannable product codes for a given location:
-  # https://developers.google.com/google-ads/api/reference/rpc/google.ads.googleads.v5.services#reachplanservice
+  # https://developers.google.com/google-ads/api/reference/rpc/latest/ReachPlanService
   push @$product_mix,
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::PlannedProduct->new(
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::PlannedProduct->new(
     {
       plannableProductCode => "TRUEVIEW_IN_STREAM",
       budgetMicros         => int($budget_micros * $trueview_allocation)});
   push @$product_mix,
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::PlannedProduct->new(
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::PlannedProduct->new(
     {
       plannableProductCode => "BUMPER",
       budgetMicros         => int($budget_micros * $bumper_allocation)});
@@ -168,7 +169,7 @@ sub forecast_suggested_mix {
 
   # Note: If preferences are too restrictive, then the response will be empty.
   my $preferences =
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::Preferences->new({
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::Preferences->new({
       hasGuaranteedPrice => "true",
       startsWithSound    => "true",
       isSkippable        => "false",
@@ -187,7 +188,7 @@ sub forecast_suggested_mix {
   my $product_mix = [];
   foreach my $product (@{$mix_response->{productAllocation}}) {
     push @$product_mix,
-      Google::Ads::GoogleAds::V5::Services::ReachPlanService::PlannedProduct->
+      Google::Ads::GoogleAds::V6::Services::ReachPlanService::PlannedProduct->
       new({
         plannableProductCode => $product->{plannableProductCode},
         budgetMicros         => $product->{budgetMicros}});
@@ -206,35 +207,35 @@ sub build_reach_request {
 
   # Valid durations are between 1 and 90 days.
   my $duration =
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::CampaignDuration->
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::CampaignDuration->
     new({
       durationInDays => 28
     });
 
   my $genders = [
-    Google::Ads::GoogleAds::V5::Common::GenderInfo->new({
+    Google::Ads::GoogleAds::V6::Common::GenderInfo->new({
         type => FEMALE
       }
     ),
-    Google::Ads::GoogleAds::V5::Common::GenderInfo->new({
+    Google::Ads::GoogleAds::V6::Common::GenderInfo->new({
         type => MALE
       })];
 
   my $devices = [
-    Google::Ads::GoogleAds::V5::Common::DeviceInfo->new({
+    Google::Ads::GoogleAds::V6::Common::DeviceInfo->new({
         type => DESKTOP
       }
     ),
-    Google::Ads::GoogleAds::V5::Common::DeviceInfo->new({
+    Google::Ads::GoogleAds::V6::Common::DeviceInfo->new({
         type => MOBILE
       }
     ),
-    Google::Ads::GoogleAds::V5::Common::DeviceInfo->new({
+    Google::Ads::GoogleAds::V6::Common::DeviceInfo->new({
         type => TABLET
       })];
 
   my $targeting =
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::Targeting->new({
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::Targeting->new({
       plannableLocationId => $location_id,
       ageRange            => AGE_RANGE_18_65_UP,
       genders             => $genders,
@@ -242,9 +243,9 @@ sub build_reach_request {
     });
 
   # See the docs for defaults and valid ranges:
-  # https://developers.google.com/google-ads/api/reference/rpc/google.ads.googleads.v5.services#google.ads.googleads.v5.services.GenerateReachForecastRequest
+  # https://developers.google.com/google-ads/api/reference/rpc/latest/GenerateReachForecastRequest
   return
-    Google::Ads::GoogleAds::V5::Services::ReachPlanService::GenerateReachForecastRequest
+    Google::Ads::GoogleAds::V6::Services::ReachPlanService::GenerateReachForecastRequest
     ->new({
       customerId            => $customer_id,
       currencyCode          => $currency_code,
@@ -269,9 +270,11 @@ sub pull_reach_curve {
       $point->{costMicros}, $point->{forecast}{onTargetReach},
       $point->{forecast}{onTargetImpressions}, $point->{forecast}{totalReach},
       $point->{forecast}{totalImpressions};
-    foreach my $product (@{$point->{forecastedProductAllocations}}) {
+    foreach my $productReachForecast (@{$point->{plannedProductReachForecasts}})
+    {
       printf "(Product: %s, Budget Micros: %d), ",
-        $product->{plannableProductCode}, $product->{budgetMicros};
+        $productReachForecast->{plannableProductCode},
+        $productReachForecast->{costMicros};
     }
     print "]'\n";
   }
